/*
* Summary:
*  main() performs following functions:
*  1: Starts the ADC and UART components.
*  2: Checks for ADC end of conversion.  Stores latest result in output
*     if conversion complete.
*  3: Checks for UART input via interruption.
*     On 'C' or 'c' received: transmits the last sample via the UART.
*     On 'S' or 's' received: continuously transmits samples as they are completed.
*/

#include <device.h>
#include "stdio.h"
#include "math.h"

// Project Defines
#define FALSE  0
#define TRUE   1

// Variables to store ADC result
int32 Output[2];
int32 Offset;
//Variable used to select ADC channel
char Channel[2];
// Variable to store UART received character
char Ch;
// Flags used to store transmit data commands
char ContinuouslySendData;
// Transmit Buffer
char TransmitBuffer[160];

//Interrups

CY_ISR(InterTX)
{
    /*
    // Send data based on last UART command
    if(ContinuouslySendData)
    {
        // Format ADC result for transmition 
        sprintf(TransmitBuffer, "Sample: %ld mV\r\n", Output);
        // Send out the data
        UART_PutString(TransmitBuffer);
        // Reset the send once flag
    }
    */
}

CY_ISR(InterRX)
{
    // Non-blocking call to get the latest data recieved
    Ch = UART_GetChar();
    switch(Ch)
    {
        // Set flags based on UART command
        case 'S':
        case 's':
            ContinuouslySendData = TRUE;
            UART_PutString("ADC Start"); 
        break;
        case 'X':
        case 'x':
            ContinuouslySendData = FALSE;
            UART_PutString("ADC Stop"); 
        break;
        case '1':
            Channel[0] = TRUE;
            Channel[1] = FALSE;
            UART_PutString("ADC Start CH1"); 
        break;
        case '2':
            Channel[0] = FALSE;
            Channel[1] = TRUE;
            UART_PutString("ADC Start CH2");
        break;
        default:
            // Place error handling code here
        break;    
        }
}

//Main code

int main(void)
{    
    
    
    // Start the components
    CyGlobalIntEnable; 
    Timer_Start();
    AMux_1_Start();
    ADC_Start();
    UART_Start();
    
    //Initialize interruptions
    isrSend_StartEx(InterTX);
    isrReceive_StartEx(InterRX);
    
    // Initialize Variables
    ContinuouslySendData = FALSE;
    Channel[0] = FALSE;
    Channel[1] = FALSE;
    //The offset is for removing the +2.5V of the input
    Offset = 30000;
    
    // Start the ADC conversion
    ADC_StartConvert();
    
    // Send message to verify COM port is connected properly
    UART_PutString("COM Port Open");
    
    for(;;)
    {                   
        // Check to see if an ADC conversion has completed
        if(ADC_IsEndConversion(ADC_WAIT_FOR_RESULT))
        {
            
            //Channel 1 select
            if(Channel[0])
            {
                AMux_1_FastSelect(0);
                Output[0] = ADC_CountsTo_mVolts(ADC_GetResult32());
                // Send data based on last UART command
                if(ContinuouslySendData)
                {   
                    // Format ADC result for transmition 
                    sprintf(TransmitBuffer, "Sample: %5ld mV\r\n", Output[0]);
                    // Send out the data
                    UART_PutString(TransmitBuffer);
                    // Reset the send once flag
                }  
            }
            
            //Channel 2 select
            if(Channel[1])
            {
                AMux_1_FastSelect(1);
                Output[1] = ADC_CountsTo_mVolts(ADC_GetResult32());      
                // Send data based on last UART command
                if(ContinuouslySendData)
                {   
                    // Format ADC result for transmition 
                    sprintf(TransmitBuffer, "Sample: %5ld mV\r\n", Output[1]);
                    // Send out the data
                    UART_PutString(TransmitBuffer);
                    // Reset the send once flag
                }  
            }
        }
    }
}

// [] END OF FILE
